# coding=utf-8
from functools import wraps


def get_mac_address():
    import uuid
    mac = uuid.UUID(int=uuid.getnode()).hex[-12:].upper()
    return '%s:%s:%s:%s:%s:%s' % (mac[0:2], mac[2:4], mac[4:6], mac[6:8], mac[8:10], mac[10:])


def assert_auth(func):
    @wraps(func)
    def _wrapper(*args, **kwargs):
        from .client import FaxDataClient
        if not FaxDataClient.instance():
            raise Exception("请先执行faxdatasdk.auth(username, password)进行登录认证")
        else:
            return func(*args, **kwargs)

    return _wrapper



import thriftpy2 as thriftpy
import six

api_description = """
struct Query_Response {
    1:required bool status,
    2:optional string msg,
    5:optional string error
}

struct Query_Request {
    1:required string method_name,
    2:required binary params,
}

struct Submit_Request {
    1:required string strategy_code,
    2:required binary params,
    3:required binary data,
}

service DataService {
    string ping(),
    Query_Response query(1:Query_Request req),
    Query_Response auth(1:string username, 2:string password, 5:bool compress, 8:string mac, 10:string version),
    Query_Response auth_by_token(1:string token, 2:string audience),
    Query_Response submit(1:Submit_Request req)
}
"""
thrift = thriftpy.load_fp(six.StringIO(api_description), "api_thrift")



# coding=utf-8
from .client import FaxDataClient
from .version import __version__, version_info  # noqa
from .api import *  # noqa
from .utils import *  # noqa


def auth(username, password, host=None, port=None):
    """账号认证"""
    FaxDataClient.set_auth_params(host=host, port=port, username=username, password=password)


def auth_by_token(token, host=None, port=None, audience="resource-client"):
    """使用 token 认证账号"""
    FaxDataClient.set_auth_params(host=host, port=port, token=token, audience=audience)


@assert_auth
def request(method, url, params=None, data=None, json=None, **kwargs):
    return FaxDataClient.instance().request(method=method, url=url, params=params, data=data, json=json, **kwargs)


@assert_auth
def post(url, params=None, data=None, json=None, **kwargs):
    return FaxDataClient.instance().request(method='post', url=url, params=params, data=data, json=json, **kwargs)


@assert_auth
def get(url, params=None, data=None, json=None, **kwargs):
    return FaxDataClient.instance().request(method='get', url=url, params=params, data=data, json=json, **kwargs)


__all__ = [
    "auth",
    "auth_by_token",
    "request",
    "post",
    "get",
    "__version__"
]
__all__.extend(api.__all__)  # noqa
